#!/bin/bash
#
# Normally, editing this script should not be required.
#
# To specify an alternative Java Runtime Environment, uncomment the following line and edit the path
if [ "$SMARTGIT_JAVA_HOME" = "" ] ; then
	SMARTGIT_JAVA_HOME=$JAVA_HOME
fi

if [ "$SMARTGIT_MAX_HEAP_SIZE" = "" ] ; then
	SMARTGIT_MAX_HEAP_SIZE=256m
fi

_JAVA_EXEC="java"
if [ "$SMARTGIT_JAVA_HOME" != "" ] ; then
    _TMP="$SMARTGIT_JAVA_HOME/bin/java"
    if [ -f "$_TMP" ] ; then
        if [ -x "$_TMP" ] ; then
            _JAVA_EXEC="$_TMP"
        else
            echo "Warning: $_TMP is not executable"
        fi
    else
        echo "Warning: $_TMP does not exist"
    fi
fi

if ! which "$_JAVA_EXEC" >/dev/null ; then
    echo "Error: No java environment found"
    exit 1
fi

#
# Resolve the location of the SmartGit installation.
# This includes resolving any symlinks.
PRG=$0
while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
    if expr "$link" : '^/' 2> /dev/null >/dev/null; then
        PRG="$link"
    else
        PRG="`dirname "$PRG"`/$link"
    fi
done

SMARTGIT_BIN=`dirname "$PRG"`

# absolutize dir
oldpwd=`pwd`
cd "${SMARTGIT_BIN}"; SMARTGIT_BIN=`pwd`
cd "${oldpwd}"; unset oldpwd

SMARTGIT_HOME=`dirname "$SMARTGIT_BIN"`

_VM_PROPERTIES="-Dsun.io.useCanonCaches=false"

# -XX:-UseSSE42Intrinsics is used to work-around bug 6875866 of Java 1.6.0_20 (and earlier) on Intel Nehalem CPUs, e.g. Core i7
$_JAVA_EXEC -XX:-UseSSE42Intrinsics -version >/dev/null 2>/dev/null
if [ $? = 0 ] ; then
  echo "Disabling SSE42Intrinsics to work around bug 6875866."
  _VM_PROPERTIES="${_VM_PROPERTIES} -XX:-UseSSE42Intrinsics"
fi

# Uncomment the following line to change the location where SmartGit should store
# settings (the given example path will make SmartGit portable by storing the settings
# in the installation directory):
#_VM_PROPERTIES="$_VM_PROPERTIES -Dsmartgit.settings=\${smartgit.installation}/.smartgit"

$_JAVA_EXEC $_VM_PROPERTIES -Xmx${SMARTGIT_MAX_HEAP_SIZE} -Dsmartgit.vm-xmx=${SMARTGIT_MAX_HEAP_SIZE} -Dmain-class=SmartGit -jar "$SMARTGIT_HOME/lib/bootloader.jar" "$@"
